@@ -36,6 +36,7 @@ extern "C" {
 GtkWidget* gok_main_create_window (gboolean is_dock);
 void gok_main_set_cursor (GdkCursor *cursor);
 gint gok_main_open(gint argc, gchar *argv[]);
+GokKeyboard *gok_main_keyboard_find_byname (const gchar* NameKeyboard);
 gboolean gok_main_display_scan (GokKeyboard* pKeyboard, char* NameKeyboard, KeyboardTypes keyboardType, KeyboardLayouts layoutType);
 gboolean gok_main_display_scan_previous (void);
 gboolean gok_main_display_scan_previous_premade (void);
@@ -46,7 +47,7 @@ void gok_main_set_first_keyboard (GokKeyboard* pKeyboard);
 GokKeyboard* gok_main_get_current_keyboard (void);
 GtkWidget* gok_main_get_main_window (void);
 Accessible* gok_main_get_foreground_accessible (void);
-void gok_main_resize_window (GtkWidget* pWindow, gint Width, gint Height);
+void gok_main_resize_window (GtkWidget* pWindow, GokKeyboard *pKeyboard, gint Width, gint Height);
 void gok_main_store_window_center (void);
 Accessible* gok_main_get_foreground_window_accessible (void);
 void gok_main_read_keyboards (void);
@@ -57,7 +58,9 @@ void gok_main_display_error (gchar* ErrorString);
 void gok_main_display_gconf_error (void);
 gboolean gok_main_window_contains_pointer (void);
 Display *gok_main_display (void);
+gchar* gok_main_get_access_method_override (void);
 gboolean gok_main_get_extras (void);
+gboolean gok_main_get_login (void);
 
 /* private */
 void gok_main_app_change_listener (Accessible* pAccessible);
@@ -69,6 +72,7 @@ void gok_main_close (void);
 gboolean gok_main_get_use_geometry (void);
 void gok_main_get_geometry (GdkRectangle* pRectangle);
 void gok_main_update_struts (gint width, gint height);
+void gok_main_set_wm_dock (gboolean is_dock);
 
 #ifdef __cplusplus
 }
